@@ -194,7 +194,7 @@ class STEP(object):
 			"context" : self.context,
 			"workspace" : self.workspace
 		}
-		self.headers = None
+		self.headers['Accept'] = 'application/octet-stream'
 		result = self.process(path, params=params, kwargs=dict(stream=True))
 		if destination:
 			with open(destination, 'wb') as output:
@@ -324,7 +324,7 @@ class Assets(STEP):
 	#________________________________________________________________________________________________
 	@args.operation
 	def update(self, id, file):
-		with open(file) as input:
+		with open(file,'rb') as input:
 			body = input.read()
 			headers = { 'Content-Type' : 'application/octet-stream' }
 			return super().put('%s/%s/content'%(self.base, id), body=body, headers=headers)
@@ -1146,7 +1146,7 @@ class Endpoints(STEP):
 	#________________________________________________________________________________________________
 	@args.operation(help='invoke an outbound endpoint')
 	def invoke_outbound(self, id):
-		return super().post(f'outbound-integration-endponits/{id}/invoke')
+		return super().post(f'outbound-integration-endpoints/{id}/invoke')
 
 
 #====================================================================================================
